



if not exist %PREFIX%\\Library\\share\\icons\\Numix\\24\\mimetypes\\jpg.svg exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%\\Library\\share\\icons\\Numix-Light\\24\\status\\state-ok.svg exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
exit /B 0
